@@ -46,8 +46,16 @@
 # Copyright 2023 vanya20074 <vanya20074@gmail.com>                             #
 # Copyright 2024 Austin Sasko <austintyler0239@yahoo.com>                      #
 # Copyright 2024 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2024 Evan Fetsko <emfetsko@gmail.com>                              #
 # Copyright 2024 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
 # Copyright 2024 Kobbi Gal <85439776+kgal-pan@users.noreply.github.com>        #
+# Copyright 2025 Bruno Didot <bdidot@gmail.com>                                #
+# Copyright 2025 Eddie Santos <9561596+eddie-santos@users.noreply.github.com>  #
+# Copyright 2025 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2025 Matt Tuchfarber <matt@tuchfarber.com>                         #
+# Copyright 2025 Michael Kukarkin <kukarkinmm@gmail.com>                       #
+# Copyright 2025 Ryan Peach <github.essential257@passmail.net>                 #
+# Copyright 2025 a-sido <andrei.sidorenko.1993@gmail.com>                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -82,12 +90,14 @@ import github.IssueEvent
 import github.Label
 import github.Milestone
 import github.NamedUser
+import github.Organization
 import github.PaginatedList
 import github.PullRequestComment
 import github.PullRequestMergeStatus
 import github.PullRequestPart
 import github.PullRequestReview
 import github.Team
+import github.TimelineEvent
 from github import Consts
 from github.GithubObject import (
     Attribute,
@@ -103,8 +113,20 @@ from github.Issue import Issue
 from github.PaginatedList import PaginatedList
 
 if TYPE_CHECKING:
+    from github.Commit import Commit
+    from github.File import File
     from github.GitRef import GitRef
+    from github.IssueComment import IssueComment
+    from github.IssueEvent import IssueEvent
+    from github.Label import Label
+    from github.Milestone import Milestone
     from github.NamedUser import NamedUser
+    from github.PullRequestComment import PullRequestComment
+    from github.PullRequestMergeStatus import PullRequestMergeStatus
+    from github.PullRequestPart import PullRequestPart
+    from github.PullRequestReview import PullRequestReview
+    from github.Team import Team
+    from github.TimelineEvent import TimelineEvent
 
 
 class ReviewComment(TypedDict):
@@ -124,13 +146,23 @@ class PullRequest(CompletableGithubObject):
     The reference can be found here
     https://docs.github.com/en/rest/reference/pulls
 
+    The OpenAPI schema can be found at
+
+    - /components/schemas/pull-request
+    - /components/schemas/pull-request-minimal
+    - /components/schemas/pull-request-simple
+
     """
 
     def _initAttributes(self) -> None:
+        self.__links: Attribute[dict[str, Any]] = NotSet
+        self._active_lock_reason: Attribute[str] = NotSet
         self._additions: Attribute[int] = NotSet
-        self._assignee: Attribute[github.NamedUser.NamedUser] = NotSet
+        self._assignee: Attribute[NamedUser] = NotSet
         self._assignees: Attribute[list[NamedUser]] = NotSet
-        self._base: Attribute[github.PullRequestPart.PullRequestPart] = NotSet
+        self._author_association: Attribute[str] = NotSet
+        self._auto_merge: Attribute[dict[str, Any]] = NotSet
+        self._base: Attribute[PullRequestPart] = NotSet
         self._body: Attribute[str] = NotSet
         self._changed_files: Attribute[int] = NotSet
         self._closed_at: Attribute[datetime | None] = NotSet
@@ -142,53 +174,76 @@ class PullRequest(CompletableGithubObject):
         self._deletions: Attribute[int] = NotSet
         self._diff_url: Attribute[str] = NotSet
         self._draft: Attribute[bool] = NotSet
-        self._head: Attribute[github.PullRequestPart.PullRequestPart] = NotSet
+        self._head: Attribute[PullRequestPart] = NotSet
         self._html_url: Attribute[str] = NotSet
         self._id: Attribute[int] = NotSet
         self._issue_url: Attribute[str] = NotSet
-        self._labels: Attribute[list[github.Label.Label]] = NotSet
+        self._labels: Attribute[list[Label]] = NotSet
+        self._locked: Attribute[bool] = NotSet
+        self._maintainer_can_modify: Attribute[bool] = NotSet
         self._merge_commit_sha: Attribute[str] = NotSet
         self._mergeable: Attribute[bool] = NotSet
         self._mergeable_state: Attribute[str] = NotSet
         self._merged: Attribute[bool] = NotSet
         self._merged_at: Attribute[datetime | None] = NotSet
-        self._merged_by: Attribute[github.NamedUser.NamedUser] = NotSet
-        self._milestone: Attribute[github.Milestone.Milestone] = NotSet
+        self._merged_by: Attribute[NamedUser] = NotSet
+        self._milestone: Attribute[Milestone] = NotSet
+        self._node_id: Attribute[str] = NotSet
         self._number: Attribute[int] = NotSet
         self._patch_url: Attribute[str] = NotSet
         self._rebaseable: Attribute[bool] = NotSet
         self._requested_reviewers: Attribute[list[NamedUser]] = NotSet
+        self._requested_teams: Attribute[list[Team]] = NotSet
         self._review_comment_url: Attribute[str] = NotSet
         self._review_comments: Attribute[int] = NotSet
         self._review_comments_url: Attribute[str] = NotSet
         self._state: Attribute[str] = NotSet
+        self._statuses_url: Attribute[str] = NotSet
         self._title: Attribute[str] = NotSet
         self._updated_at: Attribute[datetime | None] = NotSet
         self._url: Attribute[str] = NotSet
-        self._user: Attribute[github.NamedUser.NamedUser] = NotSet
-        self._maintainer_can_modify: Attribute[bool] = NotSet
-        self._node_id: Attribute[str] = NotSet
+        self._user: Attribute[NamedUser] = NotSet
 
     def __repr__(self) -> str:
         return self.get__repr__({"number": self._number.value, "title": self._title.value})
 
+    @property
+    def _links(self) -> dict[str, Any]:
+        self._completeIfNotSet(self.__links)
+        return self.__links.value
+
+    @property
+    def active_lock_reason(self) -> str:
+        self._completeIfNotSet(self._active_lock_reason)
+        return self._active_lock_reason.value
+
     @property
     def additions(self) -> int:
         self._completeIfNotSet(self._additions)
         return self._additions.value
 
     @property
-    def assignee(self) -> github.NamedUser.NamedUser:
+    def assignee(self) -> NamedUser:
         self._completeIfNotSet(self._assignee)
         return self._assignee.value
 
     @property
-    def assignees(self) -> list[github.NamedUser.NamedUser]:
+    def assignees(self) -> list[NamedUser]:
         self._completeIfNotSet(self._assignees)
         return self._assignees.value
 
     @property
-    def base(self) -> github.PullRequestPart.PullRequestPart:
+    def author_association(self) -> str:
+        self._completeIfNotSet(self._author_association)
+        return self._author_association.value
+
+    @property
+    def auto_merge(self) -> dict[str, Any]:
+        self._completeIfNotSet(self._auto_merge)
+        return self._auto_merge.value
+
+    @property
+    def base(self) -> PullRequestPart:
         self._completeIfNotSet(self._base)
         return self._base.value
 
@@ -248,7 +303,7 @@ class PullRequest(CompletableGithubObject):
         return self._draft.value
 
     @property
-    def head(self) -> github.PullRequestPart.PullRequestPart:
+    def head(self) -> PullRequestPart:
         self._completeIfNotSet(self._head)
         return self._head.value
 
@@ -268,10 +323,20 @@ class PullRequest(CompletableGithubObject):
         return self._issue_url.value
 
     @property
-    def labels(self) -> list[github.Label.Label]:
+    def labels(self) -> list[Label]:
         self._completeIfNotSet(self._labels)
         return self._labels.value
 
+    @property
+    def locked(self) -> bool:
+        self._completeIfNotSet(self._locked)
+        return self._locked.value
+
+    @property
+    def maintainer_can_modify(self) -> bool:
+        self._completeIfNotSet(self._maintainer_can_modify)
+        return self._maintainer_can_modify.value
+
     @property
     def merge_commit_sha(self) -> str:
         self._completeIfNotSet(self._merge_commit_sha)
@@ -298,15 +363,20 @@ class PullRequest(CompletableGithubObject):
         return self._merged_at.value
 
     @property
-    def merged_by(self) -> github.NamedUser.NamedUser:
+    def merged_by(self) -> NamedUser:
         self._completeIfNotSet(self._merged_by)
         return self._merged_by.value
 
     @property
-    def milestone(self) -> github.Milestone.Milestone:
+    def milestone(self) -> Milestone:
         self._completeIfNotSet(self._milestone)
         return self._milestone.value
 
+    @property
+    def node_id(self) -> str:
+        self._completeIfNotSet(self._node_id)
+        return self._node_id.value
+
     @property
     def number(self) -> int:
         self._completeIfNotSet(self._number)
@@ -322,6 +392,16 @@ class PullRequest(CompletableGithubObject):
         self._completeIfNotSet(self._rebaseable)
         return self._rebaseable.value
 
+    @property
+    def requested_reviewers(self) -> list[NamedUser]:
+        self._completeIfNotSet(self._requested_reviewers)
+        return self._requested_reviewers.value
+
+    @property
+    def requested_teams(self) -> list[Team]:
+        self._completeIfNotSet(self._requested_teams)
+        return self._requested_teams.value
+
     @property
     def review_comment_url(self) -> str:
         self._completeIfNotSet(self._review_comment_url)
@@ -342,6 +422,11 @@ class PullRequest(CompletableGithubObject):
         self._completeIfNotSet(self._state)
         return self._state.value
 
+    @property
+    def statuses_url(self) -> str:
+        self._completeIfNotSet(self._statuses_url)
+        return self._statuses_url.value
+
     @property
     def title(self) -> str:
         self._completeIfNotSet(self._title)
@@ -352,16 +437,6 @@ class PullRequest(CompletableGithubObject):
         self._completeIfNotSet(self._updated_at)
         return self._updated_at.value
 
-    @property
-    def requested_reviewers(self) -> list[github.NamedUser.NamedUser]:
-        self._completeIfNotSet(self._requested_reviewers)
-        return self._requested_reviewers.value
-
-    @property
-    def requested_teams(self) -> list[github.Team.Team]:
-        self._completeIfNotSet(self._requested_teams)
-        return self._requested_teams.value
-
     @property
     def url(self) -> str:
         self._completeIfNotSet(self._url)
@@ -372,16 +447,6 @@ class PullRequest(CompletableGithubObject):
         self._completeIfNotSet(self._user)
         return self._user.value
 
-    @property
-    def maintainer_can_modify(self) -> bool:
-        self._completeIfNotSet(self._maintainer_can_modify)
-        return self._maintainer_can_modify.value
-
-    @property
-    def node_id(self) -> str:
-        self._completeIfNotSet(self._node_id)
-        return self._node_id.value
-
     def as_issue(self) -> Issue:
         """
         :calls: `GET /repos/{owner}/{repo}/issues/{number} <https://docs.github.com/en/rest/reference/issues>`_
@@ -389,9 +454,7 @@ class PullRequest(CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck("GET", self.issue_url)
         return github.Issue.Issue(self._requester, headers, data, completed=True)
 
-    def create_comment(
-        self, body: str, commit: github.Commit.Commit, path: str, position: int
-    ) -> github.PullRequestComment.PullRequestComment:
+    def create_comment(self, body: str, commit: github.Commit.Commit, path: str, position: int) -> PullRequestComment:
         """
         :calls: `POST /repos/{owner}/{repo}/pulls/{number}/comments <https://docs.github.com/en/rest/reference/pulls#review-comments>`_
         """
@@ -400,22 +463,22 @@ class PullRequest(CompletableGithubObject):
     def create_review_comment(
         self,
         body: str,
-        commit: github.Commit.Commit,
+        commit: github.Commit.Commit | str,
         path: str,
         # line replaces deprecated position argument, so we put it between path and side
         line: Opt[int] = NotSet,
         side: Opt[str] = NotSet,
         start_line: Opt[int] = NotSet,
-        start_side: Opt[int] = NotSet,
+        start_side: Opt[str] = NotSet,
         in_reply_to: Opt[int] = NotSet,
         subject_type: Opt[str] = NotSet,
         as_suggestion: bool = False,
-    ) -> github.PullRequestComment.PullRequestComment:
+    ) -> PullRequestComment:
         """
         :calls: `POST /repos/{owner}/{repo}/pulls/{number}/comments <https://docs.github.com/en/rest/reference/pulls#review-comments>`_
         """
         assert isinstance(body, str), body
-        assert isinstance(commit, github.Commit.Commit), commit
+        assert isinstance(commit, (github.Commit.Commit, str)), commit
         assert isinstance(path, str), path
         assert is_optional(line, int), line
         assert is_undefined(side) or side in ["LEFT", "RIGHT"], side
@@ -432,12 +495,14 @@ class PullRequest(CompletableGithubObject):
         ], subject_type
         assert isinstance(as_suggestion, bool), as_suggestion
 
+        commit_id = commit._identity if isinstance(commit, github.Commit.Commit) else commit
+
         if as_suggestion:
             body = f"```suggestion\n{body}\n```"
         post_parameters = NotSet.remove_unset_items(
             {
                 "body": body,
-                "commit_id": commit._identity,
+                "commit_id": commit_id,
                 "path": path,
                 "line": line,
                 "side": side,
@@ -451,7 +516,7 @@ class PullRequest(CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck("POST", f"{self.url}/comments", input=post_parameters)
         return github.PullRequestComment.PullRequestComment(self._requester, headers, data, completed=True)
 
-    def create_review_comment_reply(self, comment_id: int, body: str) -> github.PullRequestComment.PullRequestComment:
+    def create_review_comment_reply(self, comment_id: int, body: str) -> PullRequestComment:
         """
         :calls: `POST /repos/{owner}/{repo}/pulls/{pull_number}/comments/{comment_id}/replies <https://docs.github.com/en/rest/reference/pulls#review-comments>`_
         """
@@ -465,7 +530,7 @@ class PullRequest(CompletableGithubObject):
         )
         return github.PullRequestComment.PullRequestComment(self._requester, headers, data, completed=True)
 
-    def create_issue_comment(self, body: str) -> github.IssueComment.IssueComment:
+    def create_issue_comment(self, body: str) -> IssueComment:
         """
         :calls: `POST /repos/{owner}/{repo}/issues/{number}/comments <https://docs.github.com/en/rest/reference/issues#comments>`_
         """
@@ -482,7 +547,7 @@ class PullRequest(CompletableGithubObject):
         body: Opt[str] = NotSet,
         event: Opt[str] = NotSet,
         comments: Opt[list[ReviewComment]] = NotSet,
-    ) -> github.PullRequestReview.PullRequestReview:
+    ) -> PullRequestReview:
         """
         :calls: `POST /repos/{owner}/{repo}/pulls/{number}/reviews <https://docs.github.com/en/free-pro-team@latest/rest/pulls/reviews?apiVersion=2022-11-28#create-a-review-for-a-pull-request>`_
         """
@@ -490,16 +555,16 @@ class PullRequest(CompletableGithubObject):
         assert is_optional(body, str), body
         assert is_optional(event, str), event
         assert is_optional_list(comments, dict), comments
-        post_parameters: dict[str, Any] = NotSet.remove_unset_items({"body": body})
-        post_parameters["event"] = "COMMENT" if is_undefined(event) else event
-        if is_defined(commit):
-            post_parameters["commit_id"] = commit.sha
-        if is_defined(comments):
-            post_parameters["comments"] = comments
-        else:
-            post_parameters["comments"] = []
+        post_parameters: dict[str, Any] = NotSet.remove_unset_items(
+            {
+                "body": body,
+                "event": event,
+                "commit_id": commit.sha if is_defined(commit) else NotSet,
+                "comments": comments if is_defined(comments) else [],
+            }
+        )
         headers, data = self._requester.requestJsonAndCheck("POST", f"{self.url}/reviews", input=post_parameters)
-        return github.PullRequestReview.PullRequestReview(self._requester, headers, data, completed=True)
+        return github.PullRequestReview.PullRequestReview(self._requester, headers, data)
 
     def create_review_request(
         self,
@@ -512,6 +577,11 @@ class PullRequest(CompletableGithubObject):
         assert is_optional(reviewers, str) or is_optional_list(reviewers, str), reviewers
         assert is_optional(team_reviewers, str) or is_optional_list(team_reviewers, str), team_reviewers
 
+        if isinstance(reviewers, str):
+            reviewers = [reviewers]
+        if isinstance(team_reviewers, str):
+            team_reviewers = [team_reviewers]
+
         post_parameters = NotSet.remove_unset_items({"reviewers": reviewers, "team_reviewers": team_reviewers})
 
         headers, data = self._requester.requestJsonAndCheck(
@@ -529,6 +599,11 @@ class PullRequest(CompletableGithubObject):
         assert is_optional(reviewers, str) or is_optional_list(reviewers, str), reviewers
         assert is_optional(team_reviewers, str) or is_optional_list(team_reviewers, str), team_reviewers
 
+        if isinstance(reviewers, str):
+            reviewers = [reviewers]
+        if isinstance(team_reviewers, str):
+            team_reviewers = [team_reviewers]
+
         post_parameters = NotSet.remove_unset_items({"reviewers": reviewers, "team_reviewers": team_reviewers})
 
         headers, data = self._requester.requestJsonAndCheck(
@@ -558,13 +633,13 @@ class PullRequest(CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck("PATCH", self.url, input=post_parameters)
         self._useAttributes(data)
 
-    def get_comment(self, id: int) -> github.PullRequestComment.PullRequestComment:
+    def get_comment(self, id: int) -> PullRequestComment:
         """
         :calls: `GET /repos/{owner}/{repo}/pulls/comments/{number} <https://docs.github.com/en/rest/reference/pulls#review-comments>`_
         """
         return self.get_review_comment(id)
 
-    def get_review_comment(self, id: int) -> github.PullRequestComment.PullRequestComment:
+    def get_review_comment(self, id: int) -> PullRequestComment:
         """
         :calls: `GET /repos/{owner}/{repo}/pulls/comments/{number} <https://docs.github.com/en/rest/reference/pulls#review-comments>`_
         """
@@ -577,7 +652,7 @@ class PullRequest(CompletableGithubObject):
         sort: Opt[str] = NotSet,
         direction: Opt[str] = NotSet,
         since: Opt[datetime] = NotSet,
-    ) -> PaginatedList[github.PullRequestComment.PullRequestComment]:
+    ) -> PaginatedList[PullRequestComment]:
         """
         Warning: this only returns review comments. For normal conversation comments, use get_issue_comments.
 
@@ -595,7 +670,7 @@ class PullRequest(CompletableGithubObject):
         sort: Opt[str] = NotSet,
         direction: Opt[str] = NotSet,
         since: Opt[datetime] = NotSet,
-    ) -> PaginatedList[github.PullRequestComment.PullRequestComment]:
+    ) -> PaginatedList[PullRequestComment]:
         """
         :calls: `GET /repos/{owner}/{repo}/pulls/{number}/comments <https://docs.github.com/en/rest/reference/pulls#review-comments>`_
         :param sort: string 'created' or 'updated'
@@ -617,7 +692,7 @@ class PullRequest(CompletableGithubObject):
             url_parameters,
         )
 
-    def get_single_review_comments(self, id: int) -> PaginatedList[github.PullRequestComment.PullRequestComment]:
+    def get_single_review_comments(self, id: int) -> PaginatedList[PullRequestComment]:
         """
         :calls: `GET /repos/{owner}/{repo}/pulls/{number}/review/{id}/comments <https://docs.github.com/en/rest/reference/pulls#reviews>`_
         """
@@ -629,19 +704,19 @@ class PullRequest(CompletableGithubObject):
             None,
         )
 
-    def get_commits(self) -> PaginatedList[github.Commit.Commit]:
+    def get_commits(self) -> PaginatedList[Commit]:
         """
         :calls: `GET /repos/{owner}/{repo}/pulls/{number}/commits <https://docs.github.com/en/rest/reference/pulls>`_
         """
         return PaginatedList(github.Commit.Commit, self._requester, f"{self.url}/commits", None)
 
-    def get_files(self) -> PaginatedList[github.File.File]:
+    def get_files(self) -> PaginatedList[File]:
         """
         :calls: `GET /repos/{owner}/{repo}/pulls/{number}/files <https://docs.github.com/en/rest/reference/pulls>`_
         """
         return PaginatedList(github.File.File, self._requester, f"{self.url}/files", None)
 
-    def get_issue_comment(self, id: int) -> github.IssueComment.IssueComment:
+    def get_issue_comment(self, id: int) -> IssueComment:
         """
         :calls: `GET /repos/{owner}/{repo}/issues/comments/{id} <https://docs.github.com/en/rest/reference/issues#comments>`_
         """
@@ -649,7 +724,7 @@ class PullRequest(CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck("GET", f"{self._parentUrl(self.issue_url)}/comments/{id}")
         return github.IssueComment.IssueComment(self._requester, headers, data, completed=True)
 
-    def get_issue_comments(self) -> PaginatedList[github.IssueComment.IssueComment]:
+    def get_issue_comments(self) -> PaginatedList[IssueComment]:
         """
         :calls: `GET /repos/{owner}/{repo}/issues/{number}/comments <https://docs.github.com/en/rest/reference/issues#comments>`_
         """
@@ -660,7 +735,7 @@ class PullRequest(CompletableGithubObject):
             None,
         )
 
-    def get_issue_events(self) -> PaginatedList[github.IssueEvent.IssueEvent]:
+    def get_issue_events(self) -> PaginatedList[IssueEvent]:
         """
         :calls: `GET /repos/{owner}/{repo}/issues/{issue_number}/events <https://docs.github.com/en/rest/reference/issues#events>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.IssueEvent.IssueEvent`
@@ -673,7 +748,20 @@ class PullRequest(CompletableGithubObject):
             headers={"Accept": Consts.mediaTypeLockReasonPreview},
         )
 
-    def get_review(self, id: int) -> github.PullRequestReview.PullRequestReview:
+    def get_issue_timeline(self) -> PaginatedList[TimelineEvent]:
+        """
+        :calls `GET /repos/{owner}/{repo}/issues/{issue_number}/timeline <https://docs.github.com/en/rest/reference/issues#timeline>`_
+        :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.TimelineEvent`
+        """
+        return PaginatedList(
+            github.TimelineEvent.TimelineEvent,
+            self._requester,
+            f"{self.issue_url}/timeline",
+            None,
+            headers={"Accept": Consts.mediaTypeLockReasonPreview},
+        )
+
+    def get_review(self, id: int) -> PullRequestReview:
         """
         :calls: `GET /repos/{owner}/{repo}/pulls/{number}/reviews/{id} <https://docs.github.com/en/rest/reference/pulls#reviews>`_
         :param id: integer
@@ -684,9 +772,9 @@ class PullRequest(CompletableGithubObject):
             "GET",
             f"{self.url}/reviews/{id}",
         )
-        return github.PullRequestReview.PullRequestReview(self._requester, headers, data, completed=True)
+        return github.PullRequestReview.PullRequestReview(self._requester, headers, data)
 
-    def get_reviews(self) -> PaginatedList[github.PullRequestReview.PullRequestReview]:
+    def get_reviews(self) -> PaginatedList[PullRequestReview]:
         """
         :calls: `GET /repos/{owner}/{repo}/pulls/{number}/reviews <https://docs.github.com/en/rest/reference/pulls#reviews>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.PullRequestReview.PullRequestReview`
@@ -698,7 +786,7 @@ class PullRequest(CompletableGithubObject):
             None,
         )
 
-    def get_review_requests(self) -> tuple[PaginatedList[NamedUser], PaginatedList[github.Team.Team]]:
+    def get_review_requests(self) -> tuple[PaginatedList[NamedUser], PaginatedList[Team]]:
         """
         :calls: `GET /repos/{owner}/{repo}/pulls/{number}/requested_reviewers <https://docs.github.com/en/rest/reference/pulls#review-requests>`_
         :rtype: tuple of :class:`github.PaginatedList.PaginatedList` of :class:`github.NamedUser.NamedUser` and of :class:`github.PaginatedList.PaginatedList` of :class:`github.Team.Team`
@@ -720,7 +808,7 @@ class PullRequest(CompletableGithubObject):
             ),
         )
 
-    def get_labels(self) -> PaginatedList[github.Label.Label]:
+    def get_labels(self) -> PaginatedList[Label]:
         """
         :calls: `GET /repos/{owner}/{repo}/issues/{number}/labels <https://docs.github.com/en/rest/reference/issues#labels>`_
         """
@@ -777,7 +865,7 @@ class PullRequest(CompletableGithubObject):
         Convenience function that calls :meth:`GitRef.delete` :rtype: bool.
         """
         if not force:
-            remaining_pulls = self.head.repo.get_pulls(head=self.head.ref)
+            remaining_pulls = self.head.repo.get_pulls(head=f"{self.head.repo.owner.login}:{self.head.ref}")
             if remaining_pulls.totalCount > 0:
                 raise RuntimeError(
                     "This branch is referenced by open pull requests, set force=True to delete this branch."
@@ -817,9 +905,9 @@ class PullRequest(CompletableGithubObject):
 
         # Make the request
         _, data = self._requester.graphql_named_mutation(
-            mutation_name="enable_pull_request_auto_merge",
-            variables={"input": NotSet.remove_unset_items(variables)},
-            output="actor { avatarUrl login resourcePath url } clientMutationId",
+            mutation_name="enablePullRequestAutoMerge",
+            mutation_input=NotSet.remove_unset_items(variables),
+            output_schema="actor { avatarUrl login resourcePath url } clientMutationId",
         )
         return data
 
@@ -841,9 +929,9 @@ class PullRequest(CompletableGithubObject):
 
         # Make the request
         _, data = self._requester.graphql_named_mutation(
-            mutation_name="disable_pull_request_auto_merge",
-            variables={"input": NotSet.remove_unset_items(variables)},
-            output="actor { avatarUrl login resourcePath url } clientMutationId",
+            mutation_name="disablePullRequestAutoMerge",
+            mutation_input=NotSet.remove_unset_items(variables),
+            output_schema="actor { avatarUrl login resourcePath url } clientMutationId",
         )
         return data
 
@@ -854,7 +942,7 @@ class PullRequest(CompletableGithubObject):
         merge_method: Opt[str] = NotSet,
         sha: Opt[str] = NotSet,
         delete_branch: bool = False,
-    ) -> github.PullRequestMergeStatus.PullRequestMergeStatus:
+    ) -> PullRequestMergeStatus:
         """
         :calls: `PUT /repos/{owner}/{repo}/pulls/{number}/merge <https://docs.github.com/en/rest/reference/pulls>`_
         """
@@ -869,7 +957,7 @@ class PullRequest(CompletableGithubObject):
         if delete_branch:
             self.delete_branch()
 
-        return github.PullRequestMergeStatus.PullRequestMergeStatus(self._requester, headers, data, completed=True)
+        return github.PullRequestMergeStatus.PullRequestMergeStatus(self._requester, headers, data)
 
     def add_to_assignees(self, *assignees: github.NamedUser.NamedUser | str) -> None:
         """
@@ -919,7 +1007,61 @@ class PullRequest(CompletableGithubObject):
         )
         return status == 202
 
+    def convert_to_draft(
+        self,
+        client_mutation_id: Opt[str] = NotSet,
+    ) -> dict[str, Any]:
+        """
+        :calls: `POST /graphql <https://docs.github.com/en/graphql>`_ to convert pull request to draft
+        <https://docs.github.com/en/graphql/reference/mutations#convertpullrequesttodraft>
+        """
+        assert is_optional(client_mutation_id, str), client_mutation_id
+
+        # Define the variables
+        variables = {
+            "pullRequestId": self.node_id,
+            "clientMutationId": client_mutation_id,
+        }
+
+        # Make the request
+        _, data = self._requester.graphql_named_mutation(
+            mutation_name="convertPullRequestToDraft",
+            mutation_input=NotSet.remove_unset_items(variables),
+            output_schema="clientMutationId pullRequest { isDraft }",
+        )
+        self._useAttributes({"draft": data["pullRequest"]["isDraft"]})
+        return data
+
+    def mark_ready_for_review(
+        self,
+        client_mutation_id: Opt[str] = NotSet,
+    ) -> dict[str, Any]:
+        """
+        :calls: `POST /graphql <https://docs.github.com/en/graphql>`_ to mark pull request ready for review
+        <https://docs.github.com/en/graphql/reference/mutations#markpullrequestreadyforreview>
+        """
+        assert is_optional(client_mutation_id, str), client_mutation_id
+
+        # Define the variables
+        variables = {
+            "pullRequestId": self.node_id,
+            "clientMutationId": client_mutation_id,
+        }
+
+        # Make the request
+        _, data = self._requester.graphql_named_mutation(
+            mutation_name="markPullRequestReadyForReview",
+            mutation_input=NotSet.remove_unset_items(variables),
+            output_schema="clientMutationId pullRequest { isDraft }",
+        )
+        self._useAttributes({"draft": data["pullRequest"]["isDraft"]})
+        return data
+
     def _useAttributes(self, attributes: dict[str, Any]) -> None:
+        if "_links" in attributes:  # pragma no branch
+            self.__links = self._makeDictAttribute(attributes["_links"])
+        if "active_lock_reason" in attributes:  # pragma no branch
+            self._active_lock_reason = self._makeStringAttribute(attributes["active_lock_reason"])
         if "additions" in attributes:  # pragma no branch
             self._additions = self._makeIntAttribute(attributes["additions"])
         if "assignee" in attributes:  # pragma no branch
@@ -931,6 +1073,10 @@ class PullRequest(CompletableGithubObject):
                 self._assignees = self._makeListOfClassesAttribute(github.NamedUser.NamedUser, [attributes["assignee"]])
             else:
                 self._assignees = self._makeListOfClassesAttribute(github.NamedUser.NamedUser, [])
+        if "author_association" in attributes:  # pragma no branch
+            self._author_association = self._makeStringAttribute(attributes["author_association"])
+        if "auto_merge" in attributes:  # pragma no branch
+            self._auto_merge = self._makeDictAttribute(attributes["auto_merge"])
         if "base" in attributes:  # pragma no branch
             self._base = self._makeClassAttribute(github.PullRequestPart.PullRequestPart, attributes["base"])
         if "body" in attributes:  # pragma no branch
@@ -965,6 +1111,8 @@ class PullRequest(CompletableGithubObject):
             self._issue_url = self._makeStringAttribute(attributes["issue_url"])
         if "labels" in attributes:  # pragma no branch
             self._labels = self._makeListOfClassesAttribute(github.Label.Label, attributes["labels"])
+        if "locked" in attributes:  # pragma no branch
+            self._locked = self._makeBoolAttribute(attributes["locked"])
         if "maintainer_can_modify" in attributes:  # pragma no branch
             self._maintainer_can_modify = self._makeBoolAttribute(attributes["maintainer_can_modify"])
         if "merge_commit_sha" in attributes:  # pragma no branch
@@ -981,12 +1129,20 @@ class PullRequest(CompletableGithubObject):
             self._merged_by = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["merged_by"])
         if "milestone" in attributes:  # pragma no branch
             self._milestone = self._makeClassAttribute(github.Milestone.Milestone, attributes["milestone"])
+        if "node_id" in attributes:  # pragma no branch
+            self._node_id = self._makeStringAttribute(attributes["node_id"])
         if "number" in attributes:  # pragma no branch
             self._number = self._makeIntAttribute(attributes["number"])
         if "patch_url" in attributes:  # pragma no branch
             self._patch_url = self._makeStringAttribute(attributes["patch_url"])
         if "rebaseable" in attributes:  # pragma no branch
             self._rebaseable = self._makeBoolAttribute(attributes["rebaseable"])
+        if "requested_reviewers" in attributes:
+            self._requested_reviewers = self._makeListOfClassesAttribute(
+                github.NamedUser.NamedUser, attributes["requested_reviewers"]
+            )
+        if "requested_teams" in attributes:
+            self._requested_teams = self._makeListOfClassesAttribute(github.Team.Team, attributes["requested_teams"])
         if "review_comment_url" in attributes:  # pragma no branch
             self._review_comment_url = self._makeStringAttribute(attributes["review_comment_url"])
         if "review_comments" in attributes:  # pragma no branch
@@ -995,6 +1151,8 @@ class PullRequest(CompletableGithubObject):
             self._review_comments_url = self._makeStringAttribute(attributes["review_comments_url"])
         if "state" in attributes:  # pragma no branch
             self._state = self._makeStringAttribute(attributes["state"])
+        if "statuses_url" in attributes:  # pragma no branch
+            self._statuses_url = self._makeStringAttribute(attributes["statuses_url"])
         if "title" in attributes:  # pragma no branch
             self._title = self._makeStringAttribute(attributes["title"])
         if "updated_at" in attributes:  # pragma no branch
@@ -1003,11 +1161,3 @@ class PullRequest(CompletableGithubObject):
             self._url = self._makeStringAttribute(attributes["url"])
         if "user" in attributes:  # pragma no branch
             self._user = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["user"])
-        if "requested_reviewers" in attributes:
-            self._requested_reviewers = self._makeListOfClassesAttribute(
-                github.NamedUser.NamedUser, attributes["requested_reviewers"]
-            )
-        if "requested_teams" in attributes:
-            self._requested_teams = self._makeListOfClassesAttribute(github.Team.Team, attributes["requested_teams"])
-        if "node_id" in attributes:  # pragma no branch
-            self._node_id = self._makeStringAttribute(attributes["node_id"])
