@@ -8,6 +8,7 @@
 # Copyright 2024 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
 # Copyright 2024 Jonathan Kliem <jonathan.kliem@gmail.com>                     #
 # Copyright 2025 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2025 Soubhik Kumar Mitra <59209034+x612skm@users.noreply.github.com>#
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -27,12 +28,14 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import annotations
+
 import abc
 import base64
 import time
 from abc import ABC
 from datetime import datetime, timedelta, timezone
-from typing import TYPE_CHECKING, Callable, Dict, Optional, Union
+from typing import TYPE_CHECKING, Callable, Union
 
 import jwt
 from requests import utils
@@ -186,6 +189,19 @@ class JWT(Auth, ABC):
         return "Bearer"
 
 
+class JwtSigner:
+    def __init__(self, private_key_or_func: str | PrivateKeyGenerator, jwt_algorithm: str):
+        self._private_key_or_func = private_key_or_func
+        self._jwt_algorithm = jwt_algorithm
+
+    def jwt_sign(self, payload: dict) -> str | bytes:
+        if callable(self._private_key_or_func):
+            private_key = self._private_key_or_func()
+        else:
+            private_key = self._private_key_or_func
+        return jwt.encode(payload, key=private_key, algorithm=self._jwt_algorithm)
+
+
 class AppAuth(JWT):
     """
     This class is used to authenticate as a GitHub App.
@@ -195,23 +211,16 @@ class AppAuth(JWT):
     """
 
     @staticmethod
-    def create_jwt_sign(private_key_or_func: Union[str, PrivateKeyGenerator], jwt_algorithm: str) -> DictSignFunction:
-        def jwt_sign(payload: dict) -> Union[str, bytes]:
-            if callable(private_key_or_func):
-                private_key = private_key_or_func()
-            else:
-                private_key = private_key_or_func
-            return jwt.encode(payload, key=private_key, algorithm=jwt_algorithm)
-
-        return jwt_sign
+    def create_jwt_sign(private_key_or_func: str | PrivateKeyGenerator, jwt_algorithm: str) -> DictSignFunction:
+        return JwtSigner(private_key_or_func, jwt_algorithm).jwt_sign
 
     # v3: move * above private_key
     def __init__(
         self,
-        app_id: Union[int, str],
-        private_key: Optional[Union[str, PrivateKeyGenerator]] = None,
+        app_id: int | str,
+        private_key: str | PrivateKeyGenerator | None = None,
         *,
-        sign_func: Optional[DictSignFunction] = None,
+        sign_func: DictSignFunction | None = None,
         jwt_expiry: int = Consts.DEFAULT_JWT_EXPIRY,
         jwt_issued_at: int = Consts.DEFAULT_JWT_ISSUED_AT,
     ):
@@ -228,13 +237,13 @@ class AppAuth(JWT):
         assert isinstance(jwt_expiry, int), jwt_expiry
         assert Consts.MIN_JWT_EXPIRY <= jwt_expiry <= Consts.MAX_JWT_EXPIRY, jwt_expiry
 
-        self._app_id = app_id
+        self._app_id = str(app_id)
         self._sign_func = sign_func
         self._jwt_expiry = jwt_expiry
         self._jwt_issued_at = jwt_issued_at
 
     @property
-    def app_id(self) -> Union[int, str]:
+    def app_id(self) -> int | str:
         return self._app_id
 
     @property
@@ -244,9 +253,9 @@ class AppAuth(JWT):
     def get_installation_auth(
         self,
         installation_id: int,
-        token_permissions: Optional[Dict[str, str]] = None,
-        requester: Optional[Requester] = None,
-    ) -> "AppInstallationAuth":
+        token_permissions: dict[str, str] | None = None,
+        requester: Requester | None = None,
+    ) -> AppInstallationAuth:
         """
         Creates a github.Auth.AppInstallationAuth instance for an installation.
 
@@ -258,7 +267,7 @@ class AppAuth(JWT):
         """
         return AppInstallationAuth(self, installation_id, token_permissions, requester)
 
-    def create_jwt(self, expiration: Optional[int] = None) -> str:
+    def create_jwt(self, expiration: int | None = None) -> str:
         """
         Create a signed JWT
         https://docs.github.com/en/developers/apps/building-github-apps/authenticating-with-github-apps#authenticating-as-a-github-app
@@ -310,15 +319,15 @@ class AppInstallationAuth(Auth, WithRequester["AppInstallationAuth"]):
     """
 
     # used to fetch live access token when calling self.token
-    __integration: Optional["GithubIntegration"] = None
-    __installation_authorization: Optional[InstallationAuthorization] = None
+    __integration: GithubIntegration | None = None
+    __installation_authorization: InstallationAuthorization | None = None
 
     def __init__(
         self,
         app_auth: AppAuth,
         installation_id: int,
-        token_permissions: Optional[Dict[str, str]] = None,
-        requester: Optional[Requester] = None,
+        token_permissions: dict[str, str] | None = None,
+        requester: Requester | None = None,
     ):
         super().__init__()
 
@@ -334,7 +343,7 @@ class AppInstallationAuth(Auth, WithRequester["AppInstallationAuth"]):
         if requester is not None:
             self.withRequester(requester)
 
-    def withRequester(self, requester: Requester) -> "AppInstallationAuth":
+    def withRequester(self, requester: Requester) -> AppInstallationAuth:
         assert isinstance(requester, Requester), requester
         super().withRequester(requester.withAuth(self._app_auth))
 
@@ -346,7 +355,7 @@ class AppInstallationAuth(Auth, WithRequester["AppInstallationAuth"]):
         return self
 
     @property
-    def app_id(self) -> Union[int, str]:
+    def app_id(self) -> int | str:
         return self._app_auth.app_id
 
     @property
@@ -354,7 +363,7 @@ class AppInstallationAuth(Auth, WithRequester["AppInstallationAuth"]):
         return self._installation_id
 
     @property
-    def token_permissions(self) -> Optional[Dict[str, str]]:
+    def token_permissions(self) -> dict[str, str] | None:
         return self._token_permissions
 
     @property
@@ -397,10 +406,10 @@ class AppUserAuth(Auth, WithRequester["AppUserAuth"]):
     _client_secret: str
     _token: str
     _type: str
-    _scope: Optional[str]
-    _expires_at: Optional[datetime]
-    _refresh_token: Optional[str]
-    _refresh_expires_at: Optional[datetime]
+    _scope: str | None
+    _expires_at: datetime | None
+    _refresh_token: str | None
+    _refresh_expires_at: datetime | None
 
     # imported here to avoid circular import
     from github.ApplicationOAuth import ApplicationOAuth
@@ -412,11 +421,11 @@ class AppUserAuth(Auth, WithRequester["AppUserAuth"]):
         client_id: str,
         client_secret: str,
         token: str,
-        token_type: Optional[str] = None,
-        expires_at: Optional[datetime] = None,
-        refresh_token: Optional[str] = None,
-        refresh_expires_at: Optional[datetime] = None,
-        requester: Optional[Requester] = None,
+        token_type: str | None = None,
+        expires_at: datetime | None = None,
+        refresh_token: str | None = None,
+        refresh_expires_at: datetime | None = None,
+        requester: Requester | None = None,
     ) -> None:
         super().__init__()
 
@@ -450,7 +459,7 @@ class AppUserAuth(Auth, WithRequester["AppUserAuth"]):
             self._refresh()
         return self._token
 
-    def withRequester(self, requester: Requester) -> "AppUserAuth":
+    def withRequester(self, requester: Requester) -> AppUserAuth:
         assert isinstance(requester, Requester), requester
         super().withRequester(requester.withAuth(None))
 
@@ -491,15 +500,15 @@ class AppUserAuth(Auth, WithRequester["AppUserAuth"]):
         self._refresh_expires_at = token.refresh_expires_at
 
     @property
-    def expires_at(self) -> Optional[datetime]:
+    def expires_at(self) -> datetime | None:
         return self._expires_at
 
     @property
-    def refresh_token(self) -> Optional[str]:
+    def refresh_token(self) -> str | None:
         return self._refresh_token
 
     @property
-    def refresh_expires_at(self) -> Optional[datetime]:
+    def refresh_expires_at(self) -> datetime | None:
         return self._refresh_expires_at
 
     @property
@@ -515,8 +524,8 @@ class NetrcAuth(HTTPBasicAuth, WithRequester["NetrcAuth"]):
     def __init__(self) -> None:
         super().__init__()
 
-        self._login: Optional[str] = None
-        self._password: Optional[str] = None
+        self._login: str | None = None
+        self._password: str | None = None
 
     @property
     def username(self) -> str:
@@ -532,7 +541,7 @@ class NetrcAuth(HTTPBasicAuth, WithRequester["NetrcAuth"]):
         assert self._password is not None, "Method withRequester(Requester) must be called first"
         return self._password
 
-    def withRequester(self, requester: Requester) -> "NetrcAuth":
+    def withRequester(self, requester: Requester) -> NetrcAuth:
         assert isinstance(requester, Requester), requester
         super().withRequester(requester)
 
